Глава 1. Архитектура
Пред. |  | След.

## Глава 1. Архитектура

## Медиатека

Все звуковые файлы хранятся в специальной папке (обычно `/var/lib/ardj/music`) и имеют имена, состоящие из 32 цифр или букв от a до f. Выглядит это примерно так:

    /var/lib/ardj/music/7/7/7707be8b5c2bf7bd3316c9af384d78c7.ogg
    /var/lib/ardj/music/7/7/77aa258aebc67db32c7353c67c67b4ad.mp3
    /var/lib/ardj/music/7/7/774b2e4eaf3141c04d14da6d9dbc0807.mp3

Метаданные, используемые в работе, хранятся в базе данных и в файлы не записываются.

Для добавления файлов в медиатеку используется папка для входящих файлов, добавлять их напрямую в медиатеку бесполезно — они не будут обнаружены.

Пред. |  | След.
ardj | Начало | Рейтинг композиций